@@ -1,5 +1,5 @@
 #include <iostream>
 
 auto main() -> int {
-    std::cout << "Hello, world!";
+    std::cout << "Hello hello, world!\n";
 }
